@@ -17,6 +17,7 @@ import os
 import re
 import sys
 import json
+import stat
 import errno
 import signal
 import logging
@@ -88,9 +89,11 @@ class ShellTestCase(TestCase, AdaptedConfigurationTestCaseMixIn):
                         )
                     )
                 sfh.write(
-                    #'#!/usr/bin/env python{0}.{1}\n'.format(*sys.version_info),
+                    '#!{0}\n'.format(sys.executable) +
                     '\n'.join(script_template).format(script_name.replace('salt-', ''))
                 )
+            st = os.stat(script_path)
+            os.chmod(script_path, st.st_mode | stat.S_IEXEC)
 
         return script_path
 
@@ -124,11 +127,11 @@ class ShellTestCase(TestCase, AdaptedConfigurationTestCaseMixIn):
         )
         return self.run_script('salt-ssh', arg_str, with_retcode=with_retcode, catch_stderr=catch_stderr, raw=True)
 
-    def run_run(self, arg_str, with_retcode=False, catch_stderr=False, async=False, timeout=60):
+    def run_run(self, arg_str, with_retcode=False, catch_stderr=False, async=False, timeout=60, config_dir=None):
         '''
         Execute salt-run
         '''
-        arg_str = '-c {0}{async_flag} -t {timeout} {1}'.format(self.get_config_dir(),
+        arg_str = '-c {0}{async_flag} -t {timeout} {1}'.format(config_dir or self.get_config_dir(),
                                                  arg_str,
                                                  timeout=timeout,
                                                  async_flag=' --async' if async else '')
@@ -212,7 +215,8 @@ class ShellTestCase(TestCase, AdaptedConfigurationTestCaseMixIn):
 
         popen_kwargs = {
             'shell': True,
-            'stdout': subprocess.PIPE
+            'stdout': subprocess.PIPE,
+            'universal_newlines': True
         }
 
         if catch_stderr is True:
