@@ -169,14 +169,18 @@ def generate_vm_name(options):
     '''
     vm_name_prefix = os.environ.get('JENKINS_VM_NAME_PREFIX', 'Z')
     if 'BUILD_TAG' in os.environ:
-        return '{0}_{1}'.format(
+        return '{0}{1}'.format(
             vm_name_prefix,
             os.environ.get('BUILD_TAG').replace(
                 'jenkins', 'jk').replace(
-                    'salt-cloud', 'cloud').replace(
-                        'nightly', 'ntly').replace(
-                            'salt', 'slt').replace(
-                                'linode', 'lin')
+                'salt-cloud', 'cloud').replace(
+                'nightly', 'ntly').replace(
+                'salt-', '').replace(
+                'salt', 'slt').replace(
+                'linode', 'lin').replace(
+                '.', '_').replace(
+                'branch_tests', '').replace(
+                'branch-tests', '')
         )
     else:
         random_part = hashlib.md5(
@@ -227,6 +231,12 @@ def build_pillar_data(options, convert_to_yaml=True):
     if options.test_pillar:
         pillar.update(dict(options.test_pillar))
 
+    if options.test_with_new_coverage:
+        pillar['new_coverage'] = True
+
+    if options.test_with_python3:
+        pillar['py3'] = True
+
     if convert_to_yaml is True:
         return to_cli_yaml(pillar)
     return pillar
@@ -321,6 +331,8 @@ def bootstrap_cloud_minion(options):
     script_args = ['-ZD']
     if options.no_color:
         script_args.append('-n')
+    if options.pip_based:
+        script_args.append('-P')
     if options.bootstrap_salt_url != SALT_GIT_URL:
         script_args.extend([
             '-g', options.bootstrap_salt_url
@@ -504,6 +516,8 @@ def get_minion_python_executable(options):
     try:
         python_executable = json.loads(stdout.strip())
         python_executable = python_executable[options.vm_name]
+        if options.test_with_python3:
+            python_executable = '/usr/bin/python3'
         setattr(options, 'minion_python_executable', python_executable)
         save_state(options)
         return python_executable
@@ -867,6 +881,12 @@ def main():
         default=False,
         help='Salt LXC Deployment'
     )
+    deployment_group.add_argument(
+        '--pip-based',
+        action='store_true',
+        default=False,
+        help='Allow pip based installations'
+    )
     deployment_group.add_argument(
         '--lxc-host',
         default=None,
@@ -933,8 +953,10 @@ def main():
     testing_source_options.add_argument(
         '--test-transport',
         default='zeromq',
-        choices=('zeromq', 'raet'),
-        help='Set to raet to run integration tests with raet transport. Default: %(default)s')
+        choices=('zeromq', 'raet', 'tcp'),
+        help=('Select which transport to run the integration tests with, '
+              'zeromq, raet, or tcp. Default: %(default)s')
+    )
     testing_source_options.add_argument(
         '--test-git-url',
         default=None,
@@ -958,6 +980,18 @@ def main():
         action='store_true',
         help='When running the tests default command, remove the coverage related flags.'
     )
+    testing_source_options.add_argument(
+        '--test-with-new-coverage',
+        default=False,
+        action='store_true',
+        help='When running the tests default command, run coverage using a more inclusive approach.'
+    )
+    testing_source_options.add_argument(
+        '--test-with-python3',
+        default=False,
+        action='store_true',
+        help='Use python3 instead of python2 to run the test suite'
+    )
     testing_source_options.add_argument(
         '--test-prep-sls',
         default=[],
@@ -1090,19 +1124,48 @@ def main():
 
     # Run the main command using SSH for realtime output
     if options.test_default_command:
-        options.test_command = (
-            '{python_executable} /testing/tests/runtests.py -v --run-destructive --sysinfo'
+        # This is a pretty naive aproach to get the coverage binary path
+        coverage_bin_path = get_minion_python_executable(options).replace('python', 'coverage')
+
+        options.test_command = '{python_executable} '
+
+        if options.test_without_coverage is False and options.test_with_new_coverage is True:
+            options.test_command += (
+                '{0} run --branch --concurrency=multiprocessing '
+                '--parallel-mode '.format(coverage_bin_path)
+            )
+
+        options.test_command += (
+            '/testing/tests/runtests.py -v --run-destructive --sysinfo'
             '{no_color} --xml=/tmp/xml-unittests-output --transport={transport} '
             '--output-columns={output_columns}'
         )
+
         pillar = build_pillar_data(options, convert_to_yaml=False)
         git_branch = pillar.get('git_branch', 'develop')
         if git_branch and git_branch not in('2014.1',):
             options.test_command += ' --ssh'
-        if options.test_without_coverage is False:
+        if options.test_without_coverage is False and options.test_with_new_coverage is False:
             options.test_command += ' --coverage-xml=/tmp/coverage.xml'
 
     if options.test_command:
+        def generate_xml_coverage_report(exit=True):
+            if options.test_without_coverage is False and options.test_with_new_coverage is True:
+                # Let's generate the new coverage report
+                cmd = '{0} {1} combine; {0} {1} xml -o /tmp/coverage.xml'.format(
+                    get_minion_python_executable(options),
+                    coverage_bin_path
+                )
+                exitcode = run_ssh_command(options, cmd)
+                if exitcode != 0:
+                    print_bulleted(
+                        options, 'The execution of the test command {0!r} failed'.format(cmd), 'RED'
+                    )
+                    sys.stdout.flush()
+                    if exit is True:
+                        parser.exit(exitcode)
+                time.sleep(1)
+
         options.test_command = options.test_command.format(
             python_executable=get_minion_python_executable(options),
             no_color=options.no_color and ' --no-color' or '',
@@ -1115,9 +1178,12 @@ def main():
                 options, 'The execution of the test command {0!r} failed'.format(options.test_command), 'RED'
             )
             sys.stdout.flush()
+            generate_xml_coverage_report(exit=False)
             parser.exit(exitcode)
         time.sleep(1)
 
+        generate_xml_coverage_report(exit=False)
+
         # If we reached here it means the test command passed, let's build
         # packages if the option is passed
         if options.build_packages:
