@@ -17,6 +17,7 @@ import time
 import signal
 import shutil
 import logging
+import platform
 import optparse
 import tempfile
 import traceback
@@ -139,7 +140,8 @@ class SaltTestingParser(optparse.OptionParser):
             xml_output_dir = os.environ.get(xml_output_dir_env_var)
         if not xml_output_dir:
             xml_output_dir = os.path.join(
-                tempfile.gettempdir(), 'xml-tests-output'
+                tempfile.gettempdir() if platform.system() != 'Darwin' else '/tmp',
+                'xml-tests-output'
             )
         self.xml_output_dir = xml_output_dir
 
@@ -419,41 +421,45 @@ class SaltTestingParser(optparse.OptionParser):
             '[%(levelname)-8s] %(message)s',
             datefmt='%H:%M:%S'
         )
+        if not hasattr(logging, 'TRACE'):
+            logging.TRACE = 5
+            logging.addLevelName(logging.TRACE, 'TRACE')
+        if not hasattr(logging, 'GARBAGE'):
+            logging.GARBAGE = 1
+            logging.addLevelName(logging.GARBAGE, 'GARBAGE')
+
+        # Default logging level: ERROR
+        logging.root.setLevel(logging.NOTSET)
+
         if self.options.tests_logfile:
             filehandler = logging.FileHandler(
                 mode='w',           # Not preserved between re-runs
                 filename=self.options.tests_logfile
             )
+            # The logs of the file are the most verbose possible
             filehandler.setLevel(logging.DEBUG)
             filehandler.setFormatter(formatter)
             logging.root.addHandler(filehandler)
-            logging.root.setLevel(logging.DEBUG)
 
             print(' * Logging tests on {0}'.format(self.options.tests_logfile))
 
         # With greater verbosity we can also log to the console
-        if self.options.verbosity > 2:
+        if self.options.verbosity >= 2:
             consolehandler = logging.StreamHandler(sys.stderr)
-            consolehandler.setLevel(logging.INFO)       # -vv
             consolehandler.setFormatter(formatter)
-            if not hasattr(logging, 'TRACE'):
-                logging.TRACE = 5
-                logging.addLevelName(logging.TRACE, 'TRACE')
-            if not hasattr(logging, 'GARBAGE'):
-                logging.GARBAGE = 1
-                logging.addLevelName(logging.GARBAGE, 'GARBAGE')
-            handled_levels = {
-                3: logging.DEBUG,   # -vvv
-                4: logging.TRACE,   # -vvvv
-                5: logging.GARBAGE  # -vvvvv
-            }
-            if self.options.verbosity > 3:
-                consolehandler.setLevel(
-                    handled_levels.get(
-                        self.options.verbosity,
-                        self.options.verbosity > 5 and 5 or 3
-                    )
-                )
+            if self.options.verbosity >= 6:     # -vvvvv
+                logging_level = logging.GARBAGE
+            elif self.options.verbosity == 5:   # -vvvv
+                logging_level = logging.TRACE
+            elif self.options.verbosity == 4:   # -vvv
+                logging_level = logging.DEBUG
+                print('DEBUG')
+            elif self.options.verbosity == 3:   # -vv
+                print('INFO')
+                logging_level = logging.INFO
+            else:
+                logging_level = logging.ERROR
+            consolehandler.setLevel(logging_level)
             logging.root.addHandler(consolehandler)
             logging.getLogger(__name__).info('Runtests logging has been setup')
 
@@ -476,10 +482,14 @@ class SaltTestingParser(optparse.OptionParser):
         Execute a unit test suite
         '''
         loader = TestLoader()
-        if load_from_name:
-            tests = loader.loadTestsFromName(display_name)
-        else:
-            tests = loader.discover(path, suffix, self.testsuite_directory)
+        try:
+            if load_from_name:
+                tests = loader.loadTestsFromName(display_name)
+            else:
+                tests = loader.discover(path, suffix, self.testsuite_directory)
+        except AttributeError:
+            print('Could not locate test \'{0}\'. Exiting.'.format(display_name))
+            sys.exit(1)
 
         header = '{0} Tests'.format(display_name)
         print_header('Starting {0}'.format(header),
