@@ -314,6 +314,7 @@ import time
 import shutil
 import fnmatch
 import logging
+import platform
 import argparse
 import tempfile
 import multiprocessing
@@ -553,8 +554,13 @@ class RuntimeVars(object):
 
 # ----- Global Variables -------------------------------------------------------------------------------------------->
 CONF_DIR = os.path.join(os.path.abspath(os.path.dirname(__file__)), '_saltconf')
-# Gentoo Portage prefers ebuild tests are rooted in ${TMPDIR}
-__TMP = os.path.join(os.environ.get('TMPDIR', tempfile.gettempdir()), 'salt-tests-tmpdir')
+SYS_TMP_DIR = os.path.realpath(
+    # Avoid ${TMPDIR} and gettempdir() on MacOS as they yield a base path too long for unix sockets:
+    # 'error: AF_UNIX path too long'
+    # Gentoo Portage prefers ebuild tests are rooted in ${TMPDIR}
+    os.environ.get('TMPDIR', tempfile.gettempdir()) if platform.system() != 'Darwin' else '/tmp'
+)
+__TMP = os.path.join(SYS_TMP_DIR, 'salt-tests-tmpdir')
 XML_OUTPUT_DIR = os.environ.get('SALT_XML_TEST_REPORTS_DIR', os.path.join(__TMP, 'xml-test-reports'))
 # <---- Global Variables ---------------------------------------------------------------------------------------------
 
@@ -837,7 +843,10 @@ class SaltRuntests(argparse.ArgumentParser):
         )
         self.output_options_group.add_argument(
             '--tests-logfile',
-            default=os.path.join(tempfile.gettempdir(), 'salt-runtests.log'),
+            default=os.path.join(
+                tempfile.gettempdir() if platform.system() != 'Darwin' else '/tmp',
+                'salt-runtests.log'
+            ),
             help='The path to the tests suite logging logfile. Default: %(default)r'
         )
         self.output_options_group.add_argument(
@@ -888,8 +897,9 @@ class SaltRuntests(argparse.ArgumentParser):
         self.tests_execution_tweaks_group.add_argument(
             '--transport',
             default='zeromq',
-            choices=('zeromq', 'raet'),
-            help='Set to raet to run integration tests with raet transport. Default: %(default)s'
+            choices=('zeromq', 'raet', 'tcp'),
+            help=('Select which transport to run the integration tests with, '
+                  'zeromq, raet, or tcp. Default: %(default)s')
         )
         self.tests_execution_tweaks_group.add_argument(
             '--run-destructive',
