@@ -1,24 +1,39 @@
 # -*- coding: utf-8 -*-
 '''
     :codeauthor: :email:`Pedro Algarvio (pedro@algarvio.me)`
-    :copyright: © 2013-2014 by the SaltStack Team, see AUTHORS for more details
-    :license: Apache 2.0, see LICENSE for more details.
 
 
-    salttesting.unit
-    ~~~~~~~~~~~~~~~~
+    ============================
+    Unittest Compatibility Layer
+    ============================
 
-    Unit test related functions
-'''
+    Compatibility layer to use :mod:`unittest <python2:unittest>` under Python
+    2.7 or `unittest2`_ under Python 2.6 without having to worry about which is
+    in use.
+
+    .. attention::
+
+        Please refer to Python's :mod:`unittest <python2:unittest>`
+        documentation as the ultimate source of information, this is just a
+        compatibility layer.
+
+    .. _`unittest2`: https://pypi.python.org/pypi/unittest2
+    '''
 
 # Import python libs
+from __future__ import absolute_import
 import sys
 import logging
-
+try:
+    import psutil
+    HAS_PSUTIL = True
+except ImportError:
+    HAS_PSUTIL = False
 
 # support python < 2.7 via unittest2
 if sys.version_info < (2, 7):
     try:
+        # pylint: disable=import-error
         from unittest2 import (
             TestLoader as _TestLoader,
             TextTestRunner as __TextTestRunner,
@@ -31,6 +46,7 @@ if sys.version_info < (2, 7):
             TextTestResult as __TextTestResult
         )
         from unittest2.case import _id
+        # pylint: enable=import-error
 
         class NewStyleClassMixin(object):
             '''
@@ -59,7 +75,6 @@ if sys.version_info < (2, 7):
         class _TextTestResult(__TextTestResult, NewStyleClassMixin):
             pass
 
-
     except ImportError:
         raise SystemExit('You need to install unittest2 to run the salt tests')
 else:
@@ -79,6 +94,25 @@ else:
 
 class TestCase(_TestCase):
 
+    def shortDescription(self):
+        desc = _TestCase.shortDescription(self)
+        if HAS_PSUTIL:
+            proc_info = ''
+            found_zombies = 0
+            try:
+                for proc in psutil.process_iter():
+                    if proc.status == psutil.STATUS_ZOMBIE:
+                        found_zombies += 1
+                proc_info = '[CPU:{0}%|MEM:{1}%|Z:{2}] {short_desc}'.format(psutil.cpu_percent(),
+                                                                   psutil.virtual_memory().percent,
+                                                                   found_zombies,
+                                                                   short_desc=desc if desc else '')
+            except Exception:
+                pass
+            return proc_info
+        else:
+            return _TestCase.shortDescription(self)
+
     def assertEquals(self, *args, **kwargs):
         raise DeprecationWarning(
             'The {0}() function is deprecated. Please start using {1}() '
